"use strict";

import transform from 'css-to-react-native';
const ALLOWED_STYLE_PROPERTIES = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
  textDecoration: true
};
function parseFontStyle(fontStyle) {
  if (!fontStyle) return {};
  const styles = {};
  if (fontStyle.includes('italic')) styles.fontStyle = 'italic';
  if (fontStyle.includes('bold')) styles.fontWeight = 'bold';
  return styles;
}
export function getStylesFromShikiTheme(theme) {
  console.log('Processing theme:', {
    name: theme.name,
    settingsCount: theme.settings?.length,
    hasColors: !!theme.colors
  });
  const styles = {
    root: {
      backgroundColor: theme.bg || theme.colors?.['editor.background'] || '#000000',
      color: theme.fg || theme.colors?.['editor.foreground'] || '#ffffff'
    }
  };
  console.log('Root styles:', styles.root);

  // Convert theme settings to styles
  theme.settings?.forEach((setting, index) => {
    if (setting.scope && setting.settings) {
      const scopes = Array.isArray(setting.scope) ? setting.scope : [setting.scope];
      console.log('Processing setting:', {
        index,
        scopes,
        settings: setting.settings
      });
      const fontStyles = parseFontStyle(setting.settings.fontStyle);
      scopes.forEach(scope => {
        const style = cleanStyle({
          color: setting.settings.foreground,
          backgroundColor: setting.settings.background,
          ...fontStyles
        });
        console.log('Generated style for scope:', {
          scope,
          style
        });
        styles[scope] = style;
      });
    }
  });
  return styles;
}
export function cleanStyle(style) {
  const styles = Object.entries(style).filter(([key, value]) => ALLOWED_STYLE_PROPERTIES[key] && value !== undefined).map(([key, value]) => [key, value]);
  return transform(styles);
}
//# sourceMappingURL=style.js.map